@@ -2,11 +2,11 @@
 #
 # An example of a simple Excel chart with Python and XlsxWriter.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('chart.xlsx')
+workbook = xlsxwriter.Workbook('chart.xlsx')
 worksheet = workbook.add_worksheet()
 
 # Create a new Chart object.
